@@ -459,65 +459,3 @@ validateType <- function(x, null, call) {
 validateName <- function(name, call = parent.frame()) {
   omopgenerics::assertCharacter(name, length = 1, null = TRUE, call = call)
 }
-
-checkCategory <- function(category, overlap = FALSE, type = "numeric", call = parent.frame()) {
-  omopgenerics::assertList(category, class = type, call = call)
-
-  if (is.null(names(category))) {
-    names(category) <- rep("", length(category))
-  }
-
-  # check length
-  category <- lapply(category, function(x) {
-    if (length(x) == 1) {
-      x <- c(x, x)
-    } else if (length(x) > 2) {
-      cli::cli_abort(
-        "Please specify only two values (lower bound and upper bound) per category",
-        call = call
-      )
-    }
-    invisible(x)
-  })
-
-  # check lower bound is smaller than upper bound
-  checkLower <- unlist(lapply(category, function(x) {
-    x[1] <= x[2]
-  }))
-  if (!(all(checkLower))) {
-    "Lower bound should be equal or smaller than upper bound" |>
-      cli::cli_abort(call = call)
-  }
-
-  # built tibble
-  result <- lapply(category, function(x) {
-    dplyr::tibble(lower_bound = x[1], upper_bound = x[2])
-  }) |>
-    dplyr::bind_rows() |>
-    dplyr::mutate(category_label = names(.env$category)) |>
-    dplyr::mutate(category_label = dplyr::if_else(
-      .data$category_label == "",
-      dplyr::case_when(
-        is.infinite(.data$lower_bound) & is.infinite(.data$upper_bound) ~ "any",
-        is.infinite(.data$lower_bound) ~ paste(.data$upper_bound, "or below"),
-        is.infinite(.data$upper_bound) ~ paste(.data$lower_bound, "or above"),
-        TRUE ~ paste(.data$lower_bound, "to", .data$upper_bound)
-      ),
-      .data$category_label
-    )) |>
-    dplyr::arrange(.data$lower_bound)
-
-  # check overlap
-  if (!overlap) {
-    if (nrow(result) > 1) {
-      lower <- result$lower_bound[2:nrow(result)]
-      upper <- result$upper_bound[1:(nrow(result) - 1)]
-      if (!all(lower > upper)) {
-        "There can not be overlap between categories" |>
-          cli::cli_abort(call = call)
-      }
-    }
-  }
-
-  invisible(result)
-}
