@@ -14,11 +14,11 @@ test_that("check condition_occurrence and cohort1 work", {
   # mock data
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
   # check it works with cohort1 table in mockdb
-  expect_true(typeof(cdm$cohort1 %>% addPriorObservation() %>% dplyr::collect()) == "list")
-  expect_true("prior_observation" %in% colnames(cdm$cohort1 %>% addPriorObservation()))
+  expect_true(typeof(cdm$cohort1 |> addPriorObservation() |> dplyr::collect()) == "list")
+  expect_true("prior_observation" %in% colnames(cdm$cohort1 |> addPriorObservation()))
   # check it works with condition_occurrence table in mockdb
-  expect_true(typeof(cdm$condition_occurrence %>% addPriorObservation(indexDate = "condition_start_date") %>% dplyr::collect()) == "list")
-  expect_true("prior_observation" %in% colnames(cdm$condition_occurrence %>% addPriorObservation(indexDate = "condition_start_date")))
+  expect_true(typeof(cdm$condition_occurrence |> addPriorObservation(indexDate = "condition_start_date") |> dplyr::collect()) == "list")
+  expect_true("prior_observation" %in% colnames(cdm$condition_occurrence |> addPriorObservation(indexDate = "condition_start_date")))
 
   mockDisconnect(cdm = cdm)
 })
@@ -54,8 +54,8 @@ test_that("check working example with cohort1", {
     cohort2 = cohort1
   )
 
-  result <- cdm$cohort1 %>%
-    addPriorObservation() %>%
+  result <- cdm$cohort1 |>
+    addPriorObservation() |>
     dplyr::collect()
 
   expect_true(all(colnames(cohort1) %in% colnames(result)))
@@ -101,8 +101,8 @@ test_that("check working example with condition_occurrence", {
     observation_period = obs1
   )
 
-  result <- cdm$condition_occurrence %>%
-    addPriorObservation(indexDate = "condition_start_date") %>%
+  result <- cdm$condition_occurrence |>
+    addPriorObservation(indexDate = "condition_start_date") |>
     dplyr::collect()
 
   expect_true(all(
@@ -146,7 +146,7 @@ test_that("different name", {
     observation_period = obs1
   )
 
-  cdm$condition_occurrence <- cdm$condition_occurrence %>%
+  cdm$condition_occurrence <- cdm$condition_occurrence |>
     addPriorObservation(
       indexDate = "condition_start_date", priorObservationName = "ph"
     )
@@ -216,12 +216,12 @@ test_that("multiple observation periods", {
     cohort1 = cohort1
   )
 
-  cdm$cohort1a <- cdm$cohort1 %>%
+  cdm$cohort1a <- cdm$cohort1 |>
     addPriorObservation(indexDate = "cohort_start_date")
 
-  expect_true(nrow(cdm$cohort1a %>% dplyr::collect()) == 2)
+  expect_true(nrow(cdm$cohort1a |> dplyr::collect()) == 2)
   expect_true(all(
-    cdm$cohort1a %>%
+    cdm$cohort1a |>
       dplyr::pull(prior_observation) == as.numeric(difftime(
       as.Date("2012-02-01"), as.Date("2010-01-01"),
       units = "days"
